@@ -83,6 +83,7 @@ PASSWORD_PARAMETER_NAMES = (
     'CinderPassword',
     'CongressPassword',
     'DesignatePassword',
+    'DesignateRndcKey',
     'Ec2ApiPassword',
     'EtcdInitialClusterToken',
     'GlancePassword',
@@ -111,6 +112,7 @@ PASSWORD_PARAMETER_NAMES = (
     'OctaviaCaKeyPassphrase',
     'OctaviaHeartbeatKey',
     'OctaviaPassword',
+    'OpenDaylightPassword',
     'PacemakerRemoteAuthkey',
     'PankoPassword',
     'PcsdPassword',
@@ -136,13 +138,24 @@ LEGACY_HEAT_PASSWORD_RESOURCE_NAMES = (
     'RabbitCookie',
 )
 
+# List of passwords that should not be rotated by default using the
+# GeneratePasswordAction because they require some special handling
+DO_NOT_ROTATE_LIST = (
+    'BarbicanSimpleCryptoKek',
+    'KeystoneCredential0',
+    'KeystoneCredential1',
+    'KeystoneFernetKey0',
+    'KeystoneFernetKey1',
+    'KeystoneFernetKeys',
+)
+
 PLAN_NAME_PATTERN = '^[a-zA-Z0-9-]+$'
 
 # The default version of the Image API to set in overcloudrc.
 DEFAULT_IMAGE_API_VERSION = '2'
 
 # The default version of the Volume API to set in overcloudrc.
-DEFAULT_VOLUME_API_VERSION = '3'
+DEFAULT_VOLUME_API_VERSION = '3.52'
 
 # The name of the file which holds the Mistral environment contents for plan
 # import/export
