@@ -17,7 +17,6 @@
 import abc
 from concurrent import futures
 import json
-import logging
 import netifaces
 import os
 import requests
@@ -35,8 +34,10 @@ try:
 except ImportError:
     from docker import Client
 from oslo_concurrency import processutils
+from oslo_log import log as logging
 from tripleo_common.actions import ansible
 from tripleo_common.image.base import BaseImageManager
+from tripleo_common.image.exception import ImageNotFoundException
 from tripleo_common.image.exception import ImageUploaderException
 
 
@@ -48,6 +49,12 @@ SECURE_REGISTRIES = (
     'docker.io',
 )
 
+CLEANUP = (
+    CLEANUP_FULL, CLEANUP_PARTIAL, CLEANUP_NONE
+) = (
+    'full', 'partial', 'none'
+)
+
 
 def get_undercloud_registry():
     addr = 'localhost'
@@ -66,12 +73,13 @@ class ImageUploadManager(BaseImageManager):
        """
 
     def __init__(self, config_files=None, verbose=False, debug=False,
-                 dry_run=False):
+                 dry_run=False, cleanup=CLEANUP_FULL):
         if config_files is None:
             config_files = []
         super(ImageUploadManager, self).__init__(config_files)
         self.uploaders = {}
         self.dry_run = dry_run
+        self.cleanup = cleanup
 
     def discover_image_tag(self, image, tag_from_label=None):
         uploader = self.uploader('docker')
@@ -108,7 +116,8 @@ class ImageUploadManager(BaseImageManager):
 
             self.uploader(uploader).add_upload_task(
                 image_name, pull_source, push_destination,
-                append_tag, modify_role, modify_vars, self.dry_run)
+                append_tag, modify_role, modify_vars, self.dry_run,
+                self.cleanup)
 
         for uploader in self.uploaders.values():
             uploader.run_tasks()
@@ -133,7 +142,8 @@ class ImageUploader(object):
 
     @abc.abstractmethod
     def add_upload_task(self, image_name, pull_source, push_destination,
-                        append_tag, modify_role, modify_vars, dry_run):
+                        append_tag, modify_role, modify_vars, dry_run,
+                        cleanup):
         """Add an upload task to be executed later"""
         pass
 
@@ -199,7 +209,7 @@ class DockerImageUploader(ImageUploader):
     @staticmethod
     def upload_image(image_name, pull_source, push_destination,
                      insecure_registries, append_tag, modify_role,
-                     modify_vars, dry_run):
+                     modify_vars, dry_run, cleanup):
         LOG.info('imagename: %s' % image_name)
         if ':' in image_name:
             image = image_name.rpartition(':')[0]
@@ -220,18 +230,18 @@ class DockerImageUploader(ImageUploader):
         target_image = target_image_no_tag + ':' + target_tag
 
         if dry_run:
-            return source_image, target_image
+            return []
 
         if modify_role:
             if DockerImageUploader._image_exists(target_image,
                                                  insecure_registries):
-                LOG.info('Skipping upload for modified image %s' %
-                         target_image)
+                LOG.warning('Skipping upload for modified image %s' %
+                            target_image)
                 return []
         else:
             if DockerImageUploader._images_match(source_image, target_image,
                                                  insecure_registries):
-                LOG.info('Skipping upload for image %s' % image_name)
+                LOG.warning('Skipping upload for image %s' % image_name)
                 return []
 
         dockerc = Client(base_url='unix://var/run/docker.sock', version='auto')
@@ -253,8 +263,12 @@ class DockerImageUploader(ImageUploader):
 
         DockerImageUploader._push(dockerc, target_image_no_tag, tag=target_tag)
 
-        LOG.info('Completed upload for image %s' % image_name)
-        return source_image, target_image
+        LOG.warning('Completed upload for image %s' % image_name)
+        if cleanup == CLEANUP_NONE:
+            return []
+        if cleanup == CLEANUP_PARTIAL:
+            return [source_image]
+        return [source_image, target_image]
 
     @staticmethod
     @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
@@ -263,7 +277,7 @@ class DockerImageUploader(ImageUploader):
         stop=tenacity.stop_after_attempt(5)
     )
     def _pull(dockerc, image, tag=None):
-        LOG.debug('Pulling %s' % image)
+        LOG.info('Pulling %s' % image)
 
         for line in dockerc.pull(image, tag=tag, stream=True):
             status = json.loads(line)
@@ -278,7 +292,7 @@ class DockerImageUploader(ImageUploader):
         stop=tenacity.stop_after_attempt(5)
     )
     def _push(dockerc, image, tag=None):
-        LOG.debug('Pushing %s' % image)
+        LOG.info('Pushing %s' % image)
 
         for line in dockerc.push(image, tag=tag, stream=True):
             status = json.loads(line)
@@ -315,12 +329,18 @@ class DockerImageUploader(ImageUploader):
     def _image_exists(image, insecure_registries):
         try:
             DockerImageUploader._image_digest(image, insecure_registries)
-        except Exception:
+        except ImageNotFoundException:
             return False
         else:
             return True
 
     @staticmethod
+    @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
+        reraise=True,
+        retry=tenacity.retry_if_exception_type(ImageUploaderException),
+        wait=tenacity.wait_random_exponential(multiplier=1, max=10),
+        stop=tenacity.stop_after_attempt(5)
+    )
     def _inspect(image, insecure=False):
 
         cmd = ['skopeo', 'inspect']
@@ -336,6 +356,14 @@ class DockerImageUploader(ImageUploader):
 
         out, err = process.communicate()
         if process.returncode != 0:
+            not_found_msgs = (
+                'manifest unknown',
+                # returned by docker.io
+                'requested access to the resource is denied'
+            )
+            if any(n in err for n in not_found_msgs):
+                raise ImageNotFoundException('Not found image: %s\n%s' %
+                                             (image, err))
             raise ImageUploaderException('Error inspecting image: %s\n%s' %
                                          (image, err))
         return json.loads(out)
@@ -419,21 +447,25 @@ class DockerImageUploader(ImageUploader):
                                                fallback_tag)
 
     def cleanup(self, local_images):
+        if not local_images:
+            return []
+
         dockerc = Client(base_url='unix://var/run/docker.sock', version='auto')
         for image in sorted(local_images):
             if not image:
                 continue
-            LOG.info('Removing local copy of %s' % image)
+            LOG.warning('Removing local copy of %s' % image)
             try:
                 dockerc.remove_image(image)
             except docker.errors.APIError as e:
                 if e.explanation:
-                    LOG.warning(e.explanation)
+                    LOG.error(e.explanation)
                 else:
-                    LOG.warning(e)
+                    LOG.error(e)
 
     def add_upload_task(self, image_name, pull_source, push_destination,
-                        append_tag, modify_role, modify_vars, dry_run):
+                        append_tag, modify_role, modify_vars, dry_run,
+                        cleanup):
         # prime self.insecure_registries
         if pull_source:
             self.is_insecure_registry(self._image_to_url(pull_source).netloc)
@@ -442,7 +474,7 @@ class DockerImageUploader(ImageUploader):
         self.is_insecure_registry(self._image_to_url(push_destination).netloc)
         self.upload_tasks.append((image_name, pull_source, push_destination,
                                   self.insecure_registries, append_tag,
-                                  modify_role, modify_vars, dry_run))
+                                  modify_role, modify_vars, dry_run, cleanup))
 
     def run_tasks(self):
         if not self.upload_tasks:
