@@ -38,6 +38,15 @@ CONTAINER_IMAGE_PREPARE_PARAM = [{
         'name_suffix': '',
         'tag': 'current-tripleo',
         'neutron_driver': None,
+        'openshift_namespace': 'docker.io/openshift',
+        'openshift_tag': 'v3.9.0',
+        'openshift_base_image': 'origin',
+        'openshift_cockpit_namespace': 'docker.io/cockpit',
+        'openshift_cockpit_image': 'kubernetes',
+        'openshift_cockpit_tag': 'latest',
+        'openshift_etcd_namespace': 'registry.fedoraproject.org/latest',
+        'openshift_etcd_image': 'etcd',
+        'openshift_etcd_tag': 'latest',
     }
 }]
 
@@ -85,15 +94,15 @@ def build_service_filter(environment, roles_data):
         return enabled_services
 
     for service, env_path in environment.get('resource_registry', {}).items():
-        # Use the template path to determine if it represents a
-        # containerized service
-        if '/docker/services/' in env_path:
+        if not any(p in env_path for p in ['/puppet/services',
+                                           'OS::Heat::None']):
             containerized_services.add(service)
 
     return containerized_services.intersection(enabled_services)
 
 
-def container_images_prepare_multi(environment, roles_data, dry_run=False):
+def container_images_prepare_multi(environment, roles_data, dry_run=False,
+                                   cleanup=image_uploader.CLEANUP_FULL):
     """Perform multiple container image prepares and merge result
 
     Given the full heat environment and roles data, perform multiple image
@@ -155,6 +164,7 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False):
                     [f.name],
                     verbose=True,
                     dry_run=dry_run,
+                    cleanup=cleanup
                 )
                 uploader.upload()
     return env_params
@@ -260,7 +270,7 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
             image = imagename.partition('/')[2]
             imagename = '/'.join((push_destination, image))
         if append_tag:
-            entry['append_tag'] = append_tag
+            entry['modify_append_tag'] = append_tag
         if modify_role:
             entry['modify_role'] = modify_role
         if modify_vars:
