@@ -55,15 +55,18 @@ class AnsibleActionTest(base.TestCase):
 
         env = {
             'HOME': action.work_dir,
+            'ANSIBLE_LOCAL_TEMP': action.work_dir,
             'ANSIBLE_CONFIG': ansible_config_path
         }
 
+        mock_write_cfg.assert_called_once_with(action.work_dir,
+                                               self.remote_user,
+                                               ssh_private_key=None)
+
         mock_execute.assert_called_once_with(
-            'ansible', self.hosts, '-vvvvv', '--module-name',
-            self.module, '--user', self.remote_user, '--become',
-            '--become-user', self.become_user,
-            env_variables=env, cwd=action.work_dir,
-            log_errors=processutils.LogErrors.ALL
+            'ansible', self.hosts, '-vvvvv', '--module-name', self.module,
+            '--become', '--become-user', self.become_user, env_variables=env,
+            cwd=action.work_dir, log_errors=processutils.LogErrors.ALL
         )
 
 
@@ -98,16 +101,22 @@ class AnsiblePlaybookActionTest(base.TestCase):
 
         action.run(self.ctx)
 
+        mock_write_cfg.assert_called_once_with(action.work_dir,
+                                               self.remote_user,
+                                               ssh_private_key=None)
+
         pb = os.path.join(action.work_dir, 'playbook.yaml')
         env = {
             'HOME': action.work_dir,
-            'ANSIBLE_CONFIG': ansible_config_path
+            'ANSIBLE_LOCAL_TEMP': action.work_dir,
+            'ANSIBLE_CONFIG': ansible_config_path,
+            'ANSIBLE_CALLBACK_WHITELIST': 'profile_tasks',
+            'PROFILE_TASKS_TASK_OUTPUT_LIMIT': '0',
         }
 
         mock_execute.assert_called_once_with(
-            'ansible-playbook', '-v', pb, '--user',
-            self.remote_user, '--become', '--become-user', self.become_user,
-            '--extra-vars', json.dumps(self.extra_vars),
+            'ansible-playbook', '-v', pb, '--become', '--become-user',
+            self.become_user, '--extra-vars', json.dumps(self.extra_vars),
             env_variables=env, cwd=action.work_dir,
             log_errors=processutils.LogErrors.ALL)
 
@@ -184,7 +193,7 @@ class CopyConfigFileTest(base.TestCase):
             ansible_cfg_file.flush()
 
             resulting_ansible_config = ansible.write_default_ansible_cfg(
-                work_dir, base_ansible_cfg=ansible_cfg_path)
+                work_dir, None, None, None, base_ansible_cfg=ansible_cfg_path)
 
             self.assertEqual(resulting_ansible_config,
                              os.path.join(work_dir, 'ansible.cfg'))
