@@ -520,6 +520,10 @@ class DeploymentFailuresActionTest(base.TestCase):
         mock_read = mock.MagicMock()
         mock_read.read.return_value = json.dumps(test_result)
         mock_open.return_value = mock_read
+        status_return = json.loads('{"workflow_status": {"payload": '
+                                   '{"execution_id": "foo"}}}')
+        mock_yaml_load.return_value = status_return
+
         action = deployment.DeploymentFailuresAction(self.plan)
         result = action.run(self.ctx)
 
@@ -569,9 +573,34 @@ class DeploymentFailuresActionTest(base.TestCase):
 
         mock_open.side_effect = IOError()
 
+        status_return = json.loads('{"workflow_status": {"payload": '
+                                   '{"execution_id": "foo"}}}')
+        mock_yaml_load.return_value = status_return
+
         action = deployment.DeploymentFailuresAction(self.plan)
         result = action.run(self.ctx)
 
         self.assertTrue(result['message'].startswith(
                         "Ansible errors file not found at"))
         self.assertEqual({}, result['failures'])
+
+
+class ConvertStatusActionTest(base.TestCase):
+
+    def _test(self, input_value, expected_value):
+        mock_ctx = mock.MagicMock()
+        action = deployment.ConvertStatusAction(input_value)
+        result = action.run(mock_ctx)
+        self.assertEqual(result, expected_value)
+
+    def test_no_stack(self):
+        self._test('NO_STACK', 'UNDEPLOYED')
+
+    def test_in_progress(self):
+        self._test('CREATE_IN_PROGRESS', 'DEPLOYING')
+
+    def test_empty(self):
+        self._test('', 'UNKNOWN')
+
+    def test_garbage_value(self):
+        self._test('!@#$%^&*', 'UNKNOWN')
