@@ -21,6 +21,7 @@ import six
 import urllib3
 
 from oslo_concurrency import processutils
+from tripleo_common.image.exception import ImageNotFoundException
 from tripleo_common.image.exception import ImageUploaderException
 from tripleo_common.image import image_uploader
 from tripleo_common.tests import base
@@ -162,14 +163,21 @@ class TestDockerImageUploader(base.TestCase):
         push_destination = 'localhost:8787'
         push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
 
-        self.uploader.upload_image(image + ':' + tag,
-                                   None,
-                                   push_destination,
-                                   set(),
-                                   None,
-                                   None,
-                                   None,
-                                   False)
+        self.assertEqual(
+            ['docker.io/tripleomaster/heat-docker-agents-centos:latest',
+             'localhost:8787/tripleomaster/heat-docker-agents-centos:latest'],
+            self.uploader.upload_image(
+                image + ':' + tag,
+                None,
+                push_destination,
+                set(),
+                None,
+                None,
+                None,
+                False,
+                'full'
+            )
+        )
 
         self.dockermock.assert_called_once_with(
             base_url='unix://var/run/docker.sock', version='auto')
@@ -198,7 +206,8 @@ class TestDockerImageUploader(base.TestCase):
                                    None,
                                    None,
                                    None,
-                                   False)
+                                   False,
+                                   'full')
 
         self.dockermock.assert_called_once_with(
             base_url='unix://var/run/docker.sock', version='auto')
@@ -226,14 +235,20 @@ class TestDockerImageUploader(base.TestCase):
         tag = 'latest'
         push_destination = 'localhost:8787'
 
-        self.uploader.upload_image(image + ':' + tag,
-                                   None,
-                                   push_destination,
-                                   set(),
-                                   None,
-                                   None,
-                                   None,
-                                   False)
+        self.assertEqual(
+            [],
+            self.uploader.upload_image(
+                image + ':' + tag,
+                None,
+                push_destination,
+                set(),
+                None,
+                None,
+                None,
+                False,
+                'full'
+            )
+        )
 
         # both digests are the same, no pull/push
         self.dockermock.assert_not_called()
@@ -245,13 +260,11 @@ class TestDockerImageUploader(base.TestCase):
     @mock.patch('tripleo_common.actions.'
                 'ansible.AnsiblePlaybookAction', autospec=True)
     def test_modify_upload_image(self, mock_ansible, mock_popen):
-        result1 = {
-            'Digest': 'a'
-        }
         mock_process = mock.Mock()
-        mock_process.communicate.return_value = json.dumps(result1)
+        mock_process.communicate.return_value = (
+            '', 'FATA[0000] Error reading manifest: manifest unknown')
 
-        mock_process.returncode = 0
+        mock_process.returncode = 1
         mock_popen.return_value = mock_process
 
         image = 'docker.io/tripleomaster/heat-docker-agents-centos'
@@ -275,14 +288,21 @@ class TestDockerImageUploader(base.TestCase):
             'hosts': 'localhost'
         }]
 
-        self.uploader.upload_image(image + ':' + tag,
-                                   None,
-                                   push_destination,
-                                   set(),
-                                   append_tag,
-                                   'add-foo-plugin',
-                                   {'foo_version': '1.0.1'},
-                                   False)
+        # test response for a partial cleanup
+        self.assertEqual(
+            ['docker.io/tripleomaster/heat-docker-agents-centos:latest'],
+            self.uploader.upload_image(
+                image + ':' + tag,
+                None,
+                push_destination,
+                set(),
+                append_tag,
+                'add-foo-plugin',
+                {'foo_version': '1.0.1'},
+                False,
+                'partial'
+            )
+        )
 
         self.dockermock.assert_called_once_with(
             base_url='unix://var/run/docker.sock', version='auto')
@@ -301,13 +321,10 @@ class TestDockerImageUploader(base.TestCase):
     @mock.patch('tripleo_common.actions.'
                 'ansible.AnsiblePlaybookAction', autospec=True)
     def test_modify_image_failed(self, mock_ansible, mock_popen):
-        result1 = {
-            'Digest': 'a'
-        }
         mock_process = mock.Mock()
-        mock_process.communicate.return_value = json.dumps(result1)
+        mock_process.communicate.return_value = ('', 'manifest unknown')
 
-        mock_process.returncode = 0
+        mock_process.returncode = 1
         mock_popen.return_value = mock_process
 
         image = 'docker.io/tripleomaster/heat-docker-agents-centos'
@@ -322,7 +339,7 @@ class TestDockerImageUploader(base.TestCase):
             processutils.ProcessExecutionError,
             self.uploader.upload_image,
             image + ':' + tag, None, push_destination, set(), append_tag,
-            'add-foo-plugin', {'foo_version': '1.0.1'}, False
+            'add-foo-plugin', {'foo_version': '1.0.1'}, False, 'full'
         )
 
         self.dockermock.assert_called_once_with(
@@ -344,7 +361,6 @@ class TestDockerImageUploader(base.TestCase):
         tag = 'latest'
         append_tag = 'modify-123'
         push_destination = 'localhost:8787'
-        push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
 
         result = self.uploader.upload_image(
             image + ':' + tag,
@@ -354,19 +370,14 @@ class TestDockerImageUploader(base.TestCase):
             append_tag,
             'add-foo-plugin',
             {'foo_version': '1.0.1'},
-            True
+            True,
+            'full'
         )
 
         self.dockermock.assert_not_called()
         mock_ansible.assert_not_called()
         mock_process.communicate.assert_not_called()
-
-        # the push image is still returned even though no modify or push
-        # occured
-        self.assertEqual((
-            '%s:%s' % (image, tag),
-            '%s:%s%s' % (push_image, tag, append_tag)
-        ), result)
+        self.assertEqual([], result)
 
     @mock.patch('tripleo_common.image.image_uploader.'
                 'DockerImageUploader._inspect')
@@ -388,7 +399,8 @@ class TestDockerImageUploader(base.TestCase):
             append_tag,
             'add-foo-plugin',
             {'foo_version': '1.0.1'},
-            False
+            False,
+            'full'
         )
 
         self.dockermock.assert_not_called()
@@ -468,8 +480,9 @@ class TestDockerImageUploader(base.TestCase):
 
         # inspect call failed
         mock_process.returncode = 1
+        mock_process.communicate.return_value = ('', 'manifest unknown')
         self.assertRaises(
-            ImageUploaderException,
+            ImageNotFoundException,
             self.uploader.discover_image_tag,
             'docker.io/t/foo',
             'rdo_version')
