@@ -171,7 +171,17 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
                 'tag': 'current-tripleo',
-                'neutron_driver': None
+                'neutron_driver': None,
+                'openshift_namespace': 'docker.io/openshift',
+                'openshift_tag': 'v3.9.0',
+                'openshift_base_image': 'origin',
+                'openshift_cockpit_namespace': 'docker.io/cockpit',
+                'openshift_cockpit_image': 'kubernetes',
+                'openshift_cockpit_tag': 'latest',
+                'openshift_etcd_namespace': 'registry.fedoraproject.org'
+                '/latest',
+                'openshift_etcd_image': 'etcd',
+                'openshift_etcd_tag': 'latest',
             },
             builder.container_images_template_inputs()
         )
@@ -185,7 +195,16 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'name_prefix': 'prefix-',
                 'name_suffix': '-suffix',
                 'tag': 'master',
-                'neutron_driver': 'ovn'
+                'neutron_driver': 'ovn',
+                'openshift_namespace': 'docker.io/openshift3',
+                'openshift_tag': 'v3.10.0',
+                'openshift_base_image': 'ose',
+                'openshift_cockpit_namespace': 'docker.io/openshift-cockpit',
+                'openshift_cockpit_image': 'cockpit',
+                'openshift_cockpit_tag': 'tag',
+                'openshift_etcd_namespace': 'registry.access.redhat.com/rhel7',
+                'openshift_etcd_image': 'openshift-etcd',
+                'openshift_etcd_tag': 'tag',
             },
             builder.container_images_template_inputs(
                 namespace='192.0.2.0:5000/tripleomaster',
@@ -196,6 +215,15 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 name_suffix='suffix',
                 tag='master',
                 neutron_driver='ovn',
+                openshift_namespace='docker.io/openshift3',
+                openshift_tag='v3.10.0',
+                openshift_base_image='ose',
+                openshift_cockpit_namespace='docker.io/openshift-cockpit',
+                openshift_cockpit_image='cockpit',
+                openshift_cockpit_tag='tag',
+                openshift_etcd_namespace='registry.access.redhat.com/rhel7',
+                openshift_etcd_image='openshift-etcd',
+                openshift_etcd_tag='tag',
             )
         )
 
@@ -457,9 +485,14 @@ class TestPrepare(base.TestCase):
                 'push_destination': '192.0.2.0:8787',
             }],
             'environments/containers-default-parameters.yaml': {
-                'DockerNovaApiImage': '192.0.2.0:8787/t/p-nova-api:l',
-                'DockerNovaConfigImage': '192.0.2.0:8787/t/p-nova-api:l',
-                'DockerNovaMetadataImage': '192.0.2.0:8787/t/p-nova-api:l'
+                'DockerNovaApiImage':
+                '192.0.2.0:8787/t/p-nova-api:l',
+                'DockerNovaConfigImage':
+                '192.0.2.0:8787/t/p-nova-api:l',
+                'DockerNovaMetadataConfigImage':
+                u'192.0.2.0:8787/t/p-nova-api:l',
+                'DockerNovaMetadataImage':
+                '192.0.2.0:8787/t/p-nova-api:l'
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
@@ -664,7 +697,10 @@ class TestPrepare(base.TestCase):
         self.assertEqual(
             set([
                 'OS::TripleO::Services::NovaApi',
-                'OS::TripleO::Services::NovaCompute'
+                'OS::TripleO::Services::NovaCompute',
+                'OS::TripleO::Services::OpenShift::Master',
+                'OS::TripleO::Services::Kubernetes::Worker',
+                'OS::TripleO::Services::SkydiveAgent',
             ]),
             kb.build_service_filter({
                 'resource_registry': {
@@ -674,6 +710,14 @@ class TestPrepare(base.TestCase):
                     '/tht/docker/services/foo.yaml',
                     'OS::TripleO::Services::NovaCompute':
                     '/tht/docker/services/foo.yaml',
+                    'OS::TripleO::Services::OpenShift::Master':
+                    'extraconfig/services/openshift-master.yaml',
+                    'OS::TripleO::Services::Kubernetes::Worker':
+                    'extraconfig/services/kubernetes-worker.yaml',
+                    'OS::TripleO::Services::SkydiveAgent':
+                    'extraconfig/services/skydive-agent.yaml',
+                    'OS::TripleO::Services::Noop':
+                    'OS::Heat::None'
                 }
             }, [
                 {
@@ -681,13 +725,17 @@ class TestPrepare(base.TestCase):
                     'CountDefault': 1,
                     'ServicesDefault': [
                         'OS::TripleO::Services::NeutronApi',
-                        'OS::TripleO::Services::NovaApi'
+                        'OS::TripleO::Services::NovaApi',
+                        'OS::TripleO::Services::OpenShift::Master',
+                        'OS::TripleO::Services::SkydiveAgent',
+                        'OS::TripleO::Services::Noop'
                     ]
                 }, {
                     'name': 'Compute',
                     'CountDefault': 1,
                     'ServicesDefault': [
-                        'OS::TripleO::Services::NovaCompute'
+                        'OS::TripleO::Services::NovaCompute',
+                        'OS::TripleO::Services::Kubernetes::Worker'
                     ]
                 }, {
                     'name': 'BlockStorage',
@@ -878,7 +926,8 @@ class TestPrepare(base.TestCase):
             )
         ])
 
-        mock_im.assert_called_once_with(mock.ANY, dry_run=True, verbose=True)
+        mock_im.assert_called_once_with(mock.ANY, dry_run=True, verbose=True,
+                                        cleanup='full')
 
         self.assertEqual(
             {
