@@ -97,11 +97,13 @@ class TestConfig(base.TestCase):
         mock_mkdir.assert_has_calls(expected_mkdir_calls, any_order=True)
         mock_open.assert_has_calls(expected_calls, any_order=True)
 
+    @patch.object(ooo_config.git, 'Repo')
     @mock.patch('os.mkdir')
     @mock.patch('six.moves.builtins.open')
     @patch.object(ooo_config.shutil, 'rmtree')
     def test_overcloud_config_wrong_config_type(self, mock_rmtree,
-                                                mock_open, mock_mkdir):
+                                                mock_open, mock_mkdir,
+                                                mock_repo):
         args = {'name': 'overcloud', 'config_dir': '/tmp/tht',
                 'config_type': ['bad_config']}
         heat = mock.MagicMock()
@@ -414,6 +416,7 @@ class TestConfig(base.TestCase):
         self.assertRaises(ValueError,
                           self.config.download_config, stack, self.tmp_dir)
 
+    @patch.object(ooo_config.git, 'Repo')
     @patch.object(ooo_config.shutil, 'copyfile')
     @patch.object(ooo_config.Config, '_mkdir')
     @patch.object(ooo_config.Config, '_open_file')
@@ -424,7 +427,8 @@ class TestConfig(base.TestCase):
                                                    mock_rmtree,
                                                    mock_open,
                                                    mock_mkdir,
-                                                   mock_copyfile):
+                                                   mock_copyfile,
+                                                   mock_repo):
         config_type_list = ['config_settings', 'global_config_settings',
                             'logging_sources', 'monitoring_subscriptions',
                             'service_config_settings',
@@ -567,3 +571,48 @@ class TestConfig(base.TestCase):
                 self._get_yaml_file(os.path.join(
                     'overcloud-novacompute-2',
                     d)))
+
+    @patch('tripleo_common.utils.config.Config.get_config_dict')
+    @patch('tripleo_common.utils.config.Config.get_deployment_data')
+    @patch.object(ooo_config.yaml, 'safe_load')
+    def test_validate_config(self, mock_yaml, mock_deployment_data,
+                             mock_config_dict):
+        stack_config = """
+        Controller:
+          ctlplane:
+            overcloud-controller-0.ctlplane.localdomain
+        Compute:
+          ctlplane:
+            overcloud-novacompute-0.ctlplane.localdomain
+            overcloud-novacompute-1.ctlplane.localdomain
+            overcloud-novacompute-2.ctlplane.localdomain
+        """
+        yaml_file = '/tmp/testfile.yaml'
+        heat = mock.MagicMock()
+        heat.stacks.get.return_value = fakes.create_tht_stack()
+        self.config = ooo_config.Config(heat)
+        self.config.validate_config(stack_config, yaml_file)
+        expected_yaml_safe_load_calls = [call(stack_config)]
+        mock_yaml.assert_has_calls(expected_yaml_safe_load_calls)
+
+    @patch('tripleo_common.utils.config.Config.get_config_dict')
+    @patch('tripleo_common.utils.config.Config.get_deployment_data')
+    def test_validate_config_invalid_yaml(self, mock_deployment_data,
+                                          mock_config_dict):
+        # Use invalid YAML to assert that we properly handle the exception
+        stack_config = """
+        Controller:
+          ctlplane:
+            overcloud-controller-0.ctlplane.localdomain
+        Compute:
+          ctlplane:
+        overcloud-novacompute-0.ctlplane.localdomain
+        overcloud-novacompute-1.ctlplane.localdomain
+        overcloud-novacompute-2.ctlplane.localdomain
+        """
+        yaml_file = '/tmp/testfile.yaml'
+        heat = mock.MagicMock()
+        heat.stacks.get.return_value = fakes.create_tht_stack()
+        self.config = ooo_config.Config(heat)
+        self.assertRaises(yaml.scanner.ScannerError,
+                          self.config.validate_config, stack_config, yaml_file)
