@@ -227,6 +227,44 @@ class iBootDriverInfoTest(base.TestCase):
                          self.driver_info.unique_id_from_node(node))
 
 
+class UcsDriverInfoTest(base.TestCase):
+    driver_info = nodes.UcsDriverInfo()
+
+    def test_convert_key(self):
+        keys = {
+            'pm_addr': 'ucs_address',
+            'pm_user': 'ucs_username',
+            'pm_password': 'ucs_password',
+            'pm_service_profile': 'ucs_service_profile'
+        }
+        for key, expected in keys.items():
+            self.assertEqual(expected, self.driver_info.convert_key(key))
+
+        self.assertIsNone(self.driver_info.convert_key('unknown'))
+
+    def test_unique_id_from_fields(self):
+        fields = {
+            'pm_addr': '127.0.0.1',
+            'pm_user': 'user',
+            'pm_password': '123456',
+            "pm_service_profile": 'org-root/org-CPC/ls-CPC-test'
+        }
+        self.assertEqual('127.0.0.1:org-root/org-CPC/ls-CPC-test',
+                         self.driver_info.unique_id_from_fields(fields))
+
+    def test_unique_id_from_node(self):
+        node = mock.Mock(
+            driver_info={
+                'ucs_address': '127.0.0.1',
+                'ucs_username': 'user',
+                'ucs_password': '123456',
+                "ucs_service_profile": 'org-root/org-CPC/ls-CPC-test'
+            }
+        )
+        self.assertEqual('127.0.0.1:org-root/org-CPC/ls-CPC-test',
+                         self.driver_info.unique_id_from_node(node))
+
+
 class FindNodeHandlerTest(base.TestCase):
     def test_found(self):
         test = [('fake', 'fake'),
@@ -317,6 +355,34 @@ class NodesTest(base.TestCase):
         ironic.node.create.assert_has_calls([pxe_node, mock.ANY])
         ironic.port.create.assert_has_calls([port_call])
 
+    def test_register_all_nodes_with_platform(self):
+        node_list = [self._get_node()]
+        node_list[0]['root_device'] = {"serial": "abcdef"}
+        node_properties = {"cpus": "1",
+                           "memory_mb": "2048",
+                           "local_gb": "30",
+                           "cpu_arch": "amd64",
+                           "capabilities": "num_nics:6",
+                           "root_device": {"serial": "abcdef"}}
+        node_list[0].update({'platform': 'SNB'})
+        node_extra = {"tripleo_platform": "SNB"}
+        ironic = mock.MagicMock()
+        nodes.register_all_nodes(node_list, client=ironic)
+        pxe_node_driver_info = {"ipmi_address": "foo.bar",
+                                "ipmi_username": "test",
+                                "ipmi_password": "random"}
+        pxe_node = mock.call(driver="ipmi",
+                             name='node1',
+                             driver_info=pxe_node_driver_info,
+                             resource_class='baremetal',
+                             properties=node_properties,
+                             extra=node_extra)
+        port_call = mock.call(node_uuid=ironic.node.create.return_value.uuid,
+                              address='aaa', physical_network='ctlplane',
+                              local_link_connection=None)
+        ironic.node.create.assert_has_calls([pxe_node, mock.ANY])
+        ironic.port.create.assert_has_calls([port_call])
+
     def test_register_all_nodes_kernel_ramdisk(self):
         node_list = [self._get_node()]
         node_properties = {"cpus": "1",
@@ -577,6 +643,9 @@ class NodesTest(base.TestCase):
     def test_update_node_ironic_pxe_irmc(self):
         self._update_by_type('pxe_irmc')
 
+    def test_update_node_ironic_xclarity(self):
+        self._update_by_type('xclarity')
+
     def test_update_node_ironic_redfish(self):
         ironic = mock.MagicMock()
         node_map = {'mac': {}, 'pm_addr': {}}
@@ -891,6 +960,25 @@ class NodesTest(base.TestCase):
                     'pm_addr': {'foo.bar': 'id'}}
         self.assertEqual('id', nodes._get_node_id(node, handler, node_map))
 
+    def test_register_ironic_node_xclarity(self):
+        node_properties = {"cpus": "1",
+                           "memory_mb": "2048",
+                           "local_gb": "30",
+                           "cpu_arch": "amd64",
+                           "capabilities": "num_nics:6"}
+        node = self._get_node()
+        node['pm_type'] = 'xclarity'
+        node['pm_port'] = '4444'
+        client = mock.MagicMock()
+        nodes.register_ironic_node(node, client=client)
+        client.node.create.assert_called_once_with(
+            driver='xclarity', name='node1', properties=node_properties,
+            resource_class='baremetal',
+            driver_info={'xclarity_password': 'random',
+                         'xclarity_address': 'foo.bar',
+                         'xclarity_username': 'test',
+                         'xclarity_port': '4444'})
+
 
 class TestPopulateNodeMapping(base.TestCase):
     def test_populate_node_mapping_ironic(self):
@@ -978,6 +1066,12 @@ VALID_NODE_JSON = [
      'pm_user': 'root',
      'pm_password': 'foobar',
      'pm_system_id': '/redfish/v1/Systems/1'},
+    {'pm_type': 'ipmi',
+     'pm_addr': '1.1.1.1',
+     'pm_user': 'root',
+     'pm_password': 'p@$$w0rd',
+     'arch': 'x86_64',
+     'platform': 'SNB'},
 ]
 
 
@@ -1089,8 +1183,10 @@ class TestValidateNodes(base.TestCase):
 
     def test_missing_fields(self):
         for field in ('pm_addr', 'pm_user', 'pm_password'):
+            # NOTE(tonyb): We can't use ipmi here as it's fine with some of
+            # these fields being missing.
             nodes_json = [
-                {'pm_type': 'pxe_ipmitool',
+                {'pm_type': 'pxe_drac',
                  'pm_addr': '1.1.1.1',
                  'pm_user': 'root',
                  'pm_password': 'p@$$w0rd'},
@@ -1101,6 +1197,31 @@ class TestValidateNodes(base.TestCase):
                                    'fields are missing: %s' % field,
                                    nodes.validate_nodes, nodes_json)
 
+    def test_missing_arch_with_platform_fail(self):
+        nodes_json = [
+            {'pm_type': 'ipmi',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd',
+             'platform': 'SNB'},
+        ]
+
+        msg = 'You have specified a platform without an architecture'
+        self.assertRaisesRegex(exception.InvalidNode,
+                               msg,
+                               nodes.validate_nodes, nodes_json)
+
+    def test_ipmi_missing_user_ok(self):
+        nodes_json = [
+            {'pm_type': 'ipmi',
+             'pm_addr': '1.1.1.1',
+             'pm_password': 'p@$$w0rd'},
+        ]
+
+        # validate_nodes() doesn't have an explicit return which means python
+        # gives us None
+        self.assertEqual(None, nodes.validate_nodes(nodes_json))
+
     def test_duplicate_redfish_node(self):
         nodes_json = [
             {'pm_type': 'redfish',
