@@ -12,6 +12,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import git
 import json
 import logging
 import os
@@ -49,7 +50,7 @@ class Config(object):
                 for idx, name in enumerate(shortnames):
                     if 'server_ids' in role_node_id_map:
                         server_id = role_node_id_map['server_ids'][role][idx]
-                        servers[server_id] = name
+                        servers[server_id] = name.lower()
         return servers
 
     def get_deployment_data(self, stack,
@@ -133,6 +134,19 @@ class Config(object):
             yaml.safe_dump(playbook, conf_file, default_flow_style=False)
         return sorted_tasks
 
+    def initialize_git_repo(self, dirname):
+        repo = git.Repo.init(dirname)
+        return repo
+
+    def snapshot_config_dir(self, repo, commit_message):
+        if repo.is_dirty(untracked_files=True):
+            self.log.info('Snapshotting {}'.format(repo.working_dir))
+            repo.index.add('*')
+            commit = repo.index.commit(commit_message)
+            self.log.info('Created commit {}'.format(commit.hexsha))
+        else:
+            self.log.info('No changes to commit')
+
     def _mkdir(self, dirname):
         if not os.path.exists(dirname):
             try:
@@ -161,6 +175,14 @@ class Config(object):
                               for i in stack.outputs}
         return stack
 
+    def validate_config(self, template_data, yaml_file):
+        try:
+            yaml.safe_load(template_data)
+        except (yaml.scanner.ScannerError, yaml.YAMLError) as e:
+            self.log.error("Config for file {} contains invalid yaml, got "
+                           "error {}".format(yaml_file, e))
+            raise e
+
     def write_config(self, stack, name, config_dir, config_type=None):
         # Get role data:
         role_data = self.stack_outputs.get('RoleData', {})
@@ -352,20 +374,30 @@ class Config(object):
                     warnings.warn(message, DeprecationWarning)
 
                 with open(deployment_path, 'w') as f:
-                    f.write(deployment_template.render(
+                    template_data = deployment_template.render(
                         deployment=d,
-                        server_id=server_ids[server]))
+                        server_id=server_ids[server])
+                    self.validate_config(template_data, deployment_path)
+                    f.write(template_data)
 
         for role, deployments in role_deployment_names.items():
             group_var_role_path = os.path.join(group_vars_dir, role)
             group_var_role_template = env.get_template('group_var_role.j2')
 
             with open(group_var_role_path, 'w') as f:
-                f.write(group_var_role_template.render(
+                template_data = group_var_role_template.render(
                     role=role,
                     pre_deployments=deployments['pre_deployments'],
-                    post_deployments=deployments['post_deployments']))
+                    post_deployments=deployments['post_deployments'])
+                self.validate_config(template_data, group_var_role_path)
+                f.write(template_data)
 
+        shutil.copyfile(
+            os.path.join(templates_path, 'deployments.yaml'),
+            os.path.join(config_dir, 'deployments.yaml'))
+
+        # Also copy deployments.yaml to the role dir for temporary backwards
+        # compatibility until https://review.openstack.org/574474 merges.
         for role_name, role in six.iteritems(role_data):
             role_path = os.path.join(config_dir, role_name)
 
@@ -378,12 +410,18 @@ class Config(object):
         return config_dir
 
     def download_config(self, name, config_dir, config_type=None,
-                        preserve_config_dir=True):
+                        preserve_config_dir=True, commit_message=None):
+
+        if commit_message is None:
+            commit_message = 'Automatic commit of config-download'
+
         # One step does it all
         stack = self.fetch_config(name)
         self.create_config_dir(config_dir, preserve_config_dir)
         self._mkdir(config_dir)
+        git_repo = self.initialize_git_repo(config_dir)
         self.log.info("Generating configuration under the directory: "
                       "%s" % config_dir)
         self.write_config(stack, name, config_dir, config_type)
+        self.snapshot_config_dir(git_repo, commit_message)
         return config_dir
